##  Scheduled Full Sync
Beyond the manual full syncs that can be triggered anytime by the SAP LeanIX admin, there are also full sync runs that take place automatically on the workspace.
Full Sync is scheduled to run at midnight related to the time zone in which the SAP LeanIX Instance is hosted.
